#
# spec file for package python-unittest-xml-reporting
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-unittest-xml-reporting
Version:        3.2.0
Release:        2.3
Summary:        PyUnit-based test runner with JUnit like XML reporting
License:        LGPL-3.0-or-later
URL:            https://github.com/xmlrunner/unittest-xml-reporting
Source:         https://github.com/xmlrunner/unittest-xml-reporting/archive/%{version}.tar.gz
# PATCH-FIX-UPSTREAM python-311.patch gh#xmlrunner/unittest-xml-reporting#274
Patch0:         python-311.patch
# PATCH-FIX-OPENSUSE Add one to the refcount for Python 3.12
Patch1:         python-312.patch
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-lxml
Provides:       python-xmlrunner = %{version}
BuildArch:      noarch
%python_subpackages

%description
unittest-xml-reporting is a unittest test runner that can save test results
to XML files that can be consumed by a wide range of tools, such as build
systems, IDEs and continuous integration servers.

%prep
%autosetup -p1 -n unittest-xml-reporting-%{version}
# Do not install the LICENSE for us.
sed -i '/data_files =/d' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/xmlrunner
%{python_sitelib}/unittest_xml_reporting-%{version}.dist-info

%changelog
* Mon Mar 18 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch python-312.patch:
  * Fiddle with the refcounting for Python 3.12.
* Tue Jan 30 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.2.0:
  * fix subtest referencing objects (#220)
  * Avoid including empty system-out and system-err when reporting
  * explicitly require lxml (#232)
  * make time measurements monotonic (#231)
  * Add outsuffix option (#238)
  * Used unittest.TextTestResult instead of an alias _TextTestResult
    removed in Python 3.11
  * Used assertRegex() instead of an alias assertRegexpMatches() removed
    in Python 3.11
  * Fix typo in tests/django_test.py.
  * Update Django testing.
  * Add LICENSE to tarball
- Switch to pyproject macros.
- Refresh python-311.patch.
* Mon Feb 20 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add python-311.patch to support python 3.11
  gh#xmlrunner/unittest-xml-reporting#274
* Wed Oct 19 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove not needed python-six dependency
- Use more specific python_sitelib in files section
- Update the source URL to the current one
* Tue Mar 10 2020 pgajdos@suse.com
- version update to 3.0.2
  * no upstream changelog found
* Fri Feb  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 2.5.2
  * add testing for python3.8
  * Fix crash when exceptions contain unicode in buffered output
* Wed Oct  2 2019 Matej Cepl <mcepl@suse.com>
- Skip test_xmlrunner_non_ascii failing with Python 3.8
  gh#xmlrunner/unittest-xml-reporting#205
* Fri Apr 12 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 2.5.1
  * no changelog available
* Tue Mar  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.1:
  * no changelog available
- Enable tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to version 2.1.0:
  * no changelog available
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Thu May 14 2015 benoit.monin@gmx.fr
- update to version 1.12.0:
  * no changelog available
- remove python-xml from requirement
- add new dependency python-six
- add new dependency python-unittest2 for SLE11
- remove sed call on testsuite.py: not needed anymore
- remove LICENSE and README.markdown: not provided anymore
* Fri Nov 15 2013 p.drouand@gmail.com
- Update to version 1.7.0
  + No changelog available
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Jan 14 2013 p.drouand@gmail.com
- Initial python3 support
* Mon Jan 14 2013 p.drouand@gmail.com
- Update to 1.4.3 version:
  * fix indentation problem
- Update to 1.4 version:
  * Refactor Django test runner to clean up imports
  * Allow bool values in TEST_OUTPUT_VERBOSE for backwards-compatibility
  * Fix Django test runner for renamed XMLTestRunner constructor parameter
  * Fixed syntax error on classifiers section.
  * Added support for Python 3.
  * Renamed constructor parameter to make it compatible with the one used
    in unittest.TextTestRunner.
* Thu Sep  8 2011 saschpe@suse.de
- Added requirement for python-xml
* Thu Sep  8 2011 saschpe@suse.de
- Initial version
